@@ -393,6 +393,18 @@ void QAptActions::runSourcesEditor()
     const QString kdesu = QFile::decodeName(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/kdesu");
     const QString editor = QStandardPaths::findExecutable("software-properties-kde");
 
+    if (editor.isEmpty()) {
+        QString text = i18nc("@label",
+                             "Could not find <command>software-properties-kde</command> "
+                             "on your system, please install it. Alternatively, you can use "
+                             "<application>Plasma Discover</application> to configure "
+                             "software sources.");
+        QString title = i18nc("@title:window",
+                              "Cannot find <command>software-properties-kde</command>");
+        KMessageBox::sorry(m_mainWindow, text, title);
+        return;
+    }
+
     arguments << kdesu << "--" << editor << QStringLiteral("--attach") << QString::number(winID);
     if (m_reloadWhenEditorFinished) {
         arguments << QStringLiteral("--dont-update");
